/**
 * Diese Datei ist Teil von „Lernstrategien“ 
 * (Dateiname: „mod_splernstrategien“), einer Plugin-Software 
 * für das moodle LMS.
 *
 * Das moodle LMS ist lizenziert mit der GNU General Public 
 * License Version 3. Aktuelle Lizenzhinweise zu moodle 
 * finden Sie unter: https://moodledev.io/general/license.
 *
 * Das Plugin ist lizenziert mit der GNU General Public 
 * License Version 3. Anzugebender Urheber des Plugins ist
 * die „metromorph softworks GmbH im Auftrag von ORCA.nrw“.
 * Die Lizenzierung umfasst nicht die Inhalte, die auf der
 * Anwenderoberfläche des Plugins angezeigt werden; diese sind 
 * ihrerseits CC BY-SA 4.0 lizenziert.
 *
 * Sie sollten eine Kopie der GNU-Lizenz zusammen mit diesem 
 * Programm erhalten haben. Sie finden sie auch unter 
 * https://www.gnu.org/licenses. Die CC-Lizenz finden Sie
 * unter https://creativecommons.org/licenses/by-sa/4.0/deed.de.
 */

/**
 * JS-module to limit amount of text in a textarea.
 *
 * Applies to all textarea.limittext nodes in the document. Appends
 * a notification node directly after the textarea.
 * Uses the cols, rows attributes to compute the maximum text to be entered.
 * Works only if connection is via https, as we use crypto.randomUUID().
 *
 * @module    mod_splernstrategien
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


define([],
    function() {
        let getLines = function(txtArea) {
            return (txtArea.value.split('\n') || []);
        };

        let checkContent = function(event) {
            if (noSpaceLeft(event) == 1) {
                if (event.key !== "Backspace" && event.key !== "Delete" && !(event.key.includes("Arrow"))) {
                    event.preventDefault();
                }
            }
        };
        var noSpaceLeft = function(event) {
            let full = 0;
            let ta = event.target;
            let maxRows = parseInt(ta.getAttribute('rows'));
            let maxCols = parseInt(ta.getAttribute('cols'));
            let numberOfLines = getLines(ta).reduce((a, b) => a + Math.ceil((b.length + 1) / maxCols), 0);
            let restP = document.getElementById(ta.dataset.msgid);
            restP.innerHTML = Math.round(numberOfLines / maxRows * 100) + "%";
            if (numberOfLines >= maxRows) {
                restP.innerHTML += " (Sie haben die maximal mögliche Anzahl an Zeilen bzw. Zeichen überschritten.)";
                full = 1;
            }
            return full;
        };
        return {
            init: () => {
                // Add event-handler
                document.querySelectorAll('textarea.limittext').forEach(
                    (item) => {
                        let id = window.crypto.randomUUID();
                        item.addEventListener('keydown', checkContent);
                        item.addEventListener('keyup', noSpaceLeft);
                        item.setAttribute('data-msgid', id);
                        let restP = document.createElement('p');
                        restP.id = id;
                        restP.style.cssText = "color: #333; font-size: 0.8em;";
                        item.after(restP);
                    }
                );
            }
        };
    });