<?php
/**
 * Diese Datei ist Teil von „Lernstrategien“ 
 * (Dateiname: „mod_splernstrategien“), einer Plugin-Software 
 * für das moodle LMS.
 *
 * Das moodle LMS ist lizenziert mit der GNU General Public 
 * License Version 3. Aktuelle Lizenzhinweise zu moodle 
 * finden Sie unter: https://moodledev.io/general/license.
 *
 * Das Plugin ist lizenziert mit der GNU General Public 
 * License Version 3. Anzugebender Urheber des Plugins ist
 * die „metromorph softworks GmbH im Auftrag von ORCA.nrw“.
 * Die Lizenzierung umfasst nicht die Inhalte, die auf der
 * Anwenderoberfläche des Plugins angezeigt werden; diese sind 
 * ihrerseits CC BY-SA 4.0 lizenziert.
 *
 * Sie sollten eine Kopie der GNU-Lizenz zusammen mit diesem 
 * Programm erhalten haben. Sie finden sie auch unter 
 * https://www.gnu.org/licenses. Die CC-Lizenz finden Sie
 * unter https://creativecommons.org/licenses/by-sa/4.0/deed.de.
 */

namespace mod_splernstrategien;

defined('MOODLE_INTERNAL') || die();


/**
 * Lernstrategien finite state machine
 * 
 * @package   mod_splernstrategien
 * @license   https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class statemachine
{
    /** @var user the user the statemachine runs for. */
    public $user;

    /** @var object the current state. */
    public $state;

    /** @var object the state before the current, NULL if no transition happened. */
    public $laststate;

    /**
     * Construct the FSM for a user.
     * 
     * @param user $user the user object.
     * @param int $state Overrides the users current state, if not NULL.
     */
    public function __construct($user, $stateid = NULL)
    {
        $this->user = $user;

        $this->set(is_null($stateid) ? $this->user->laststate : $stateid);
    }

    /**
     * Set state. This reads the state object from db.
     * \todo\reviewhelp\remove Formerly: getState of locallib.php
     * 
     * @param int $stateid ID of the state to load.
     */
    private function set($stateid)
    {
        global $DB;

        $table = "splernstrategien_modules";

        $this->laststate = $this->state;
        try {
            $this->state = $DB->get_record($table, ['state' => $stateid], $fields = '*', $strictness = MUST_EXIST);
        } catch (\Exception $e) {
            // TODO ab damit in eine gesonderte moduleinrichtung \todo YES!
            states::init(false);

            try {
                $this->state = $DB->get_record($table, ['state' => $stateid], $fields = '*', $strictness = MUST_EXIST);
            } catch (\Exception $e) {
                throw new \moodle_exception("Der aktuelle State (state-id=" . $stateid . ") existiert nicht.\n" . $e->getMessage());
            }
        }

        // We only store userdata if we change state.
        if ($this->user->laststate !== $stateid) {
            $this->user->laststate = $stateid;
            // \todo\think Is nextstate used at all? Remove otherwise, from DB too.
            $this->user->nextstate = 0;
            $this->user->delay = $this->state->delay;
            $this->user->timestamp = date_timestamp_get(date_create());
        }
    }

    /**
     * Make a state transition based on the input.
     * \todo\reviewhelp\remove Formerly: findCalcState of locallib.php
     * 
     * @param array $input key/value pairs of input.
     */
    public function transition($input)
    {
        // We only do transitions if the user is not delayed.
        if ($this->user->delay_left() > 0) {
            return;
        }

        $s = $this->state;

        // We only do a transition, when the state has been marked finished by the input.
        $finished = array_key_exists("statefinished", $input) && $s->state == $input['statefinished'];
        if (!$finished) {
            return;
        }

        if ($s->waysout && !strpos($s->waysout, ",")) {
            $this->set($s->waysout);
            return;
        }

        // If we dont find a new state below, we stay.
        $newstateid = $s->state;

        // $questions - json beschreibung liegende in Template Element Fragen (locallib.init_lernstrategien_modules())
        if ($s->questions) {
            $questionsObj = json_decode($s->questions);
            if (empty($questionsObj)) {
                throw new \moodle_exception("State has no valid question-object!");
            } else {
                foreach ($questionsObj as $htmlElementDescriptionObj) {
                    foreach ($htmlElementDescriptionObj as $val) {
                        switch ($val->type) {
                            case "select":
                            case "radio":
                                $correctArr = [];
                                $elementname = $val->name; // z.b. type=radio, name=erwartungsproblem1
                                if (array_key_exists($elementname, $input) && $input[$elementname]) {
                                    $choice = $input[$elementname];
                                    foreach ($val->options as $option) {
                                        if (property_exists($option, 'out')) {
                                            if ($option->name == $choice) {
                                                $newstateid = $option->out;
                                            }
                                        }
                                    }
                                }
                                break;

                            case "text":
                                $elementname = $val->name;
                                if (array_key_exists($elementname, $input) && $input[$elementname]) {
                                    foreach ($val->waysout as $wayout) {
                                        if (
                                            isset($wayout->values)
                                            && property_exists($wayout, 'out')
                                            && in_array($input[$elementname], $wayout->values)
                                        ) {
                                            $newstateid = $wayout->out;
                                            break;  // will not be overwritten by this Element
                                        } elseif (isset($wayout->default)) {
                                            $newstateid = $wayout->out; // may be overwritten by a later matching value
                                        }
                                    }
                                }
                                break;
                        }
                    }
                }
            }
        }
        $this->set($newstateid);
    }

    /**
     * Execute additionals transitions for special states.
     */
    public function special_transitions()
    {
        if ($this->state->type == "checkingTraces") {
            $this->set($this->user->finished_all() ? $this->state->waysout : $this->state->wayback);
        } else if ($this->state->type == "delay") {
            if ($this->user->delay_left() <= 0) {
                $this->set($this->state->waysout);
            }
        }
    }
}
