<?php
/**
 * Diese Datei ist Teil von „Lernstrategien“ 
 * (Dateiname: „mod_splernstrategien“), einer Plugin-Software 
 * für das moodle LMS.
 *
 * Das moodle LMS ist lizenziert mit der GNU General Public 
 * License Version 3. Aktuelle Lizenzhinweise zu moodle 
 * finden Sie unter: https://moodledev.io/general/license.
 *
 * Das Plugin ist lizenziert mit der GNU General Public 
 * License Version 3. Anzugebender Urheber des Plugins ist
 * die „metromorph softworks GmbH im Auftrag von ORCA.nrw“.
 * Die Lizenzierung umfasst nicht die Inhalte, die auf der
 * Anwenderoberfläche des Plugins angezeigt werden; diese sind 
 * ihrerseits CC BY-SA 4.0 lizenziert.
 *
 * Sie sollten eine Kopie der GNU-Lizenz zusammen mit diesem 
 * Programm erhalten haben. Sie finden sie auch unter 
 * https://www.gnu.org/licenses. Die CC-Lizenz finden Sie
 * unter https://creativecommons.org/licenses/by-sa/4.0/deed.de.
 */


/**
 * Generates a pdf-ouput from user input.
 *
 * @package   mod_splernstrategien
 * @license   https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require(__DIR__ . '/../../config.php');
require_once($CFG->libdir . '/pdflib.php');

global $PAGE, $OUTPUT, $USER, $_SESSION;

require_login();

$text = "";

if (!empty($_SESSION["answers"])) {
    $objAnswers = $_SESSION["answers"];
    if (property_exists($objAnswers, 'wp_strategie'))  {
        $text = $objAnswers->wp_strategie;
    } else {
        $text = "Sie haben noch keine Lösungsstrategie angegeben";
    }
    if (!$text) {
        //set some text to print
        $text = "Sie haben noch keine Lösungsstrategie angegeben";
    }

    $url = new moodle_url("/mod/splernstrategien/viewPDFc.php");
    $PAGE->set_url($url);

    $doc = new pdf;
    $doc->setPrintHeader(false);
    $doc->AddPage();
    $doc->setPrintFooter(false);
    $html = <<<EOF
    <style >
        body {
        	margin: 50px;
        }

        .inhaltstext  {
        	font-size: 4.2mm;
        	line-height: 5.9mm;

        }

        .tipp {
        	font-weight: 600;
        	font-size: 14px;
        	line-height: 5.9mm;
        	font-style: italic;
        	color: #000000;
        	margin-top: 1.5em;
        }


        .tipptext {
        	font-style: italic;
        	font-size: 12px;
        	line-height: 5.9mm;
        }


        h1, h2 {
        	font-family: "Segoe UI", "Tahoma", "sans serif";
        }

        h1 {
        	font-size: 10.2mm;
        	line-height: 5.9mm;
            font-weight: normal;
            letter-spacing: -0.5px;
        }


        h2 {
        	font-size: 20px;
        	line-height: 5.1mm;
            padding-top:0;
            margin-top: 0;
        }


        p {
        	font-family: "Segoe UI", "Tahoma", "sans serif";
            margin: 0 0 0.75em 0;
        }

        .semibold {
            font: "Segoe UI", "Tahoma", "sans serif";
            font-weight: 500;
        }

        #container_main {
        	width: 210mm;
        }

    </style>

    <h1 >Lernstrategien</h1>
    <div id="container_main">
    <h2>Wertproblem: Mein Merksatz</h2>
            <p class="inhaltstext">In dem absolvierten Modul zum richtigen Einsatz von motivationalen Lernstrategien haben Sie gelernt,
            dass es bei Vorliegen eines <strong>Wertproblems – Sie sind unmotiviert, weil Ihnen der Lerninhalt langweilig und unbedeutend
            vorkommt – </strong>helfen kann, die Strategie <strong>„Steigerung der persönlichen Bedeutsamkeit“</strong> anzuwenden.</p>
            <p class="inhaltstext">Um die Strategie in Zukunft optimal bei einem aufkommenden Wertproblem anwenden zu können,
            überlegen Sie sich, wie Sie die <strong>Relevanz des Lerninhalts steigern</strong> können: Ist der Inhalt wichtig für das Erreichen
            Ihrer (Studien-)Ziele? In welcher Situation könnten die Inhalte Ihnen weiterhelfen?</p>
            <p class="inhaltstext">Wenn Sie in Ihrem weiteren Studienverlauf ein Wertproblem diagnostizieren,
            dann reflektieren Sie zunächst, warum es sich lohnt, trotzdem fokussiert weiter zu lernen.</p>
            <p class="tipp">Tipp:</p>
            <p class="tipptext">Legen Sie sich Ihr selbst erstelltes Merkblatt griffbereit an Ihren Lernplatz oder heften Sie es sich
            an eine Pinnwand über Ihren Schreibtisch, damit Sie Ihre Strategie jederzeit im Blick haben!</p>
    </div>
    EOF;
    $doc->SetMargins(20, 0, 10);
    $doc->writeHTML($html, true, false, true, false, '');
    $doc->Image('./material/motivationsregulation/img/csspdf/feld_wertproblem.png', 20, 146, 185, 130, 'PNG', '', '', false, 300, '', false, false, 0, false, false, false);
    $doc->MultiCell($w=168, $h=0, $text, $border=0, $align='L', 
                    $fill=false, $ln=1,$x=30, $y=170, $reseth=true,
                    $stretch=0, $ishtml=false, $autopadding=true,
                    $maxh=95, $valign='T', $fitcell=true);
    $doc->Output();
}
